@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -36,7 +36,7 @@ EnvironmentPlainTextEdit::~EnvironmentPlainTextEdit()
 
 void EnvironmentPlainTextEdit::contextMenuEvent(QContextMenuEvent *event)
 {
-    if (toPlainText().isEmpty()) {
+    if (document()->isEmpty()) {
         return;
     }
     QPlainTextEdit::contextMenuEvent(event);
@@ -44,7 +44,7 @@ void EnvironmentPlainTextEdit::contextMenuEvent(QContextMenuEvent *event)
 
 void EnvironmentPlainTextEdit::paintEvent(QPaintEvent *event)
 {
-    if (toPlainText().isEmpty()) {
+    if (document()->isEmpty()) {
         QPainter p(viewport());
 
         QFont font = p.font();
